# R Skript for research data interviews by Elena Simukovic
# code: Alexander.Struck@hu-berlin.de v0.1 2014-09-29

## libraries ##
library(tm) # text mining
library(RColorBrewer)
library(wordcloud)

## variables ##
interview_dir <- '/Users/lx/Desktop/ES_interviews_txt/'
out.path <- '/Users/lx/Desktop/ES_interviews_txt/wordclouds/'
files <- list.files(path = interview_dir, recursive = TRUE, pattern = "\\.txt$") 
# pull everything that is inside a directory including subfolders matching .txt
#load(paste0(interview_dir, 'my.stopwords.RObj'))
all_words <- ''

for (f in files){
    cat("\n looking at file: ",f,"\n")
    my.text <- readLines(con <- file(paste0(interview_dir, f), encoding="UTF-8"))
    close(con)
    my.text <- gsub("\\-|\\'", " ", my.text)
    my.text <- unlist(strsplit(my.text, ' ')) # split everything at whitespace char
    my.text <- gsub("[[:punct:]]", "", my.text)    
    my.text <- gsub("[[:digit:]]", "", my.text)    
    my.text <- tolower(my.text)
    my.text <- my.text[!(my.text %in% my.stopwords)]
    all_words <- append(all_words, my.text)
}
# manual stemming
all_words <- gsub('datei', 'dateien', all_words)
all_words <- gsub('publikation', 'publikationen', all_words)
all_words <- gsub('jahren', 'jahr', all_words)
all_words <- gsub('jahre', 'jahr', all_words)
all_words <- gsub('bilder', 'bild', all_words)
all_words <- gsub('digitale', 'digital', all_words)
all_words <- gsub('kriegt', 'kriegen', all_words)
all_words <- gsub('unterschiedliche', 'verschiedene', all_words)
all_words <- gsub('kleinen', 'klein', all_words)
all_words <- gsub('lange', 'lang', all_words)
all_words <- gsub('statistische', 'statistisch', all_words)
all_words <- gsub('ergebnisse', 'ergebnis', all_words)
all_words <- gsub('publiziert', 'publizieren', all_words)
all_words <- gsub('kollegen', 'kollege', all_words)
all_words <- gsub('tabellen', 'tabelle', all_words)
all_words <- gsub('studenten', 'student', all_words)
all_words <- gsub('interviews', 'interview', all_words)
all_words <- gsub('gespeichert', 'speichern', all_words)
all_words <- gsub('analysen', 'analyse', all_words)
all_words <- gsub('methoden', 'methode', all_words)
all_words <- gsub('internationale', 'international', all_words)
all_words <- gsub('geschrieben', 'schreiben', all_words)
all_words <- gsub('doktoranden', 'doktorand', all_words)
all_words <- gsub('filme', 'film', all_words)
all_words <- gsub('monate', 'monat', all_words)
all_words <- gsub('briefe', 'brief', all_words)
all_words <- gsub('entwickelt', 'entwickeln', all_words)
all_words <- gsub('entwicklung', 'entwickeln', all_words)
all_words <- gsub('ressourcen', 'ressource', all_words)
all_words <- gsub('tiere', 'tier', all_words)
all_words <- gsub('arrays', 'array', all_words)
all_words <- gsub('interdisziplinarität', 'interdisziplinär', all_words)
all_words <- gsub('menschen', 'mensch', all_words)
all_words <- gsub('nachhaltigkeit', 'nachhaltig', all_words)
all_words <- gsub('quellen', 'quelle', all_words)
# all_words <- gsub('ag', 'arbeitsgruppe', all_words) # 'ag' is part of 'frage'
all_words <- gsub('erstellt', 'erstellen', all_words)
all_words <- gsub('modelle', 'model', all_words)
all_words <- gsub('technischen', 'technisch', all_words)
all_words <- gsub('theoretische', 'theoretisch', all_words)
all_words <- gsub('autoren', 'autor', all_words)
all_words <- gsub('gruppen', 'gruppe', all_words)
all_words <- gsub('inhaltliche', 'inhaltlich', all_words)
all_words <- gsub('sprachen', 'sprache', all_words)
all_words <- gsub('chefin', 'chef', all_words)
all_words <- gsub('externen', 'extern', all_words)
all_words <- gsub('genetischen', 'genetisch', all_words)
all_words <- gsub('genutzt', 'nutzen', all_words)
all_words <- gsub('nutzung', 'nutzen', all_words)
all_words <- gsub('gutes', 'gut', all_words)
all_words <- gsub('kostet', 'kosten', all_words)
all_words <- gsub('sequenziert', 'sequenzieren', all_words)
all_words <- gsub('versucht', 'versuchen', all_words)
all_words <- gsub('aufgenommen', 'aufnehmen', all_words)
all_words <- gsub('datenmengen', 'datenmenge', all_words)
all_words <- gsub('erfasst', 'erfassen', all_words)
all_words <- gsub('gebaut', 'bauen', all_words)
all_words <- gsub('institutionen', 'institution', all_words)
all_words <- gsub('interessiert', 'interessant', all_words)
all_words <- gsub('klinischen', 'klinisch', all_words)
all_words <- gsub('namen', 'name', all_words)
all_words <- gsub('gb', 'gigabyte', all_words)
all_words <- gsub('gearbeitet', 'arbeit', all_words)
all_words <- gsub('publikationenen', 'publikation', all_words)
all_words <- gsub('dateienen', 'datei', all_words)
all_words <- gsub('unterschiede', 'unterschied', all_words)
all_words <- gsub('neuen', 'neu', all_words)
all_words <- gsub('eigenschaften', 'eigenschaft', all_words)
all_words <- gsub('brauchte', 'brauchen', all_words)
all_words <- gsub('informationen', 'information', all_words)
all_words <- gsub('wichtige', 'wichtig', all_words)
all_words <- gsub('normale', 'normal', all_words)

# 
all_words <- all_words[nchar(all_words) > 2]
pal2 <- brewer.pal(8, 'Set2') # color palette
cat('\n stemming ... ')
all_words_stemmed <- stemDocument(all_words, language='german')
cat('\n stem completion ... please be patient')
all_new_words <- stemCompletion(all_words_stemmed, type="prevalent", all_words)
cat('\n creating wordcloud ...')
word.table <- sort(table(all_new_words), decreasing=TRUE)
word.table <- word.table[-1]
pdf(paste(out.path, 'interesting_interview_words_all.pdf'), width=7, height=7, bg = "transparent")
wordcloud(names(word.table), word.table, scale=c(9,.1), max.words=200, random.order=F, rot.per=.3, colors=pal2)
dev.off()

svg(paste(out.path, 'interesting_interview_words_all.svg'), width=7, height=7, bg = "transparent")
wordcloud(names(word.table), word.table, scale=c(9,.1), max.words=200, random.order=F, rot.per=.3, colors=pal2)
dev.off()

save(my.stopwords, file=paste0(interview_dir, "my.stopwords.RObj"))